@@ -31,12 +31,17 @@ class SpacyNERParameters(AnnotatorParameters):
     model: str = Field("en_core_web_sm",
                        description="Name of the [spacy model](https://spacy.io/models) to use for NER extraction")
     scispacy_linker: Optional[SciSpacyLinker] = Field(None,
-                                                      description="Name of the [scispacy linker](https://github.com/allenai/scispacy) which performs linking to a knowledge base.")
-    types_filter: Optional[str] = Field(None, description="Retain only entities belonging to the comma-separated list of types")
+                                                      description="""Name of the [scispacy linker](https://github.com/allenai/scispacy) which performs linking to a knowledge base.<br/>
+                                                      <b>Only valid with scispacy models</b>""")
+    types_filter: Optional[str] = Field("", description="""Comma-separated list of UMLS [semantic types](https://lhncbc.nlm.nih.gov/ii/tools/MetaMap/documentation/SemanticTypesAndGroups.html) to keep.<br/>
+                                                      For example `T028,T116,T123`<br/>
+                                                      <b>Only valid with scispacy models</b>""")
     mention_threshold: Optional[float] = Field(0.85,
-                                               description="The threshold that a entity candidate must reach to be added.")
+                                               description="""The threshold that a entity candidate must reach to be added.<br/>
+                                                      <b>Only valid with scispacy models</b>""")
     mention_max: Optional[int] = Field(1,
-                                       description="The maximum number of entities which will be returned for a given mention")
+                                       description="""The maximum number of entities which will be returned for a given mention.<br/>
+                                                      <b>Only valid with scispacy models</b>""")
 
 
 class SpacyNERAnnotator(AnnotatorBase):
@@ -49,7 +54,8 @@ class SpacyNERAnnotator(AnnotatorBase):
             cast(SpacyNERParameters, parameters)
         # Create parsing context with time and language information
         nlp, linker = get_nlp(params.model, params.scispacy_linker)
-        types_as_set = set(comma_separated_to_list(params.types_filter))
+        types_filter = comma_separated_to_list(params.types_filter.strip())
+        types_as_set = set(types_filter or [])
         for document in documents:
             document.annotations = []
             if not document.sentences:
@@ -76,12 +82,11 @@ class SpacyNERAnnotator(AnnotatorBase):
                                         terms.append(term)
                                     else:
                                         break
-                    if len(types_as_set) == 0 or len(terms) > 0:
-                        document.annotations.append(Annotation(start=start, end=end,
-                                                               labelName=ent.label_.lower(),
-                                                               label=ent.label_,
-                                                               text=document.text[start:end],
-                                                               terms=terms))
+                    document.annotations.append(Annotation(start=start, end=end,
+                                                           labelName=ent.label_.lower(),
+                                                           label=ent.label_,
+                                                           text=document.text[start:end],
+                                                           terms=terms if linker is not None else None))
         return documents
 
     @classmethod
